@@ -13,6 +13,11 @@ Build and Deploy with Kluff %s
 
 
 class AppSetup(Controller):
+    container_registry = 'localhost:5001'
+    backend_path = ''
+    frontend_path = ''
+    backend_image_tag = ''
+    frontend_image_tag = ''
     class Meta:
         label = 'items'
         stacked_type = 'embedded'
@@ -60,46 +65,38 @@ class AppSetup(Controller):
 
             self.app.log.info(f'running plugin: {plugin_name}')
 
-            backend = os.path.join(os.getcwd(), 'backend')
-            frontend = os.path.join(os.getcwd(), 'frontend')
+            self.backend_path = os.path.join(os.getcwd(), 'backend')
+            self.frontend_path = os.path.join(os.getcwd(), 'frontend')
 
-            if not os.path.exists(backend):
+            if not os.path.exists(self.backend_path):
                 print('Unable to find backend dir. Are you running kluff from inside your plugin dir?')
                 sys.exit()
 
-            if not os.path.exists(frontend):
+            if not os.path.exists(self.frontend_path):
                 print('Unable to find frontend dir. Are you running kluff from inside your plugin dir?')
                 sys.exit()
 
-            backend_docker_tag = f'{plugin_name}:backend'
-            frontend_docker_tag = f'{plugin_name}:frontend'
+            self.backend_image_tag = f'{plugin_name}:backend'
+            self.frontend_image_tag = f'{plugin_name}:frontend'
 
-            # os.system(f'cd {backend}')
-            # os.system(f'docker rm $(docker stop $(docker ps -a -q --filter ancestor={backend_docker_tag} --format="{{.ID}}"))')
-            os.system(f'cd {backend} && docker build -t {backend_docker_tag} .')
-            os.system(f'docker run -it -p 5000:5000 -d {backend_docker_tag}')
+            os.system(f'cd {self.backend_path} && docker build -t {self.backend_image_tag} .')
+            os.system(f'docker run -it -p 5000:5000 -d {self.backend_image_tag}')
 
-            # os.system(f'cd {frontend}')
-            # os.system(f'docker rm $(docker stop $(docker ps -a -q --filter ancestor={frontend_docker_tag} --format="{{.ID}}"))')
-            os.system(f'cd {frontend} && docker build -t {frontend_docker_tag} .')
-            os.system(f'docker run -it -p 3000:3000 -d {frontend_docker_tag}')
+            os.system(f'cd {self.frontend_path} && docker build -t {self.frontend_image_tag} .')
+            os.system(f'docker run -it -p 3000:3000 -d {self.frontend_image_tag}')
 
         except OSError as e:
             raise CommandError(e)
     
     @ex(
         help='deploy plugin',
-        arguments=[
-        (['plugin_name'], 
-                        {'help': 'plugin name'}
-        ),
-        ],
         )
     def deploy(self):
-        plugin_name = self.app.pargs.plugin_name
-        self.app.log.info(f'deploying plugin: {plugin_name}')
+        self.app.log.info(f'deploying plugin')
         try:
-            os.system(f'cd {plugin_name}')
-            os.system('git push')
+            os.system(f'cd {self.backend_path}')
+            os.system(f'docker build -t {self.backend_image_tag} .')
+            os.system(f'docker tag {self.backend_image_tag} {self.container_registry}/{self.backend_image_tag}')
+            os.system(f'docker push {self.container_registry}/{self.backend_image_tag}')
         except OSError as e:
             raise CommandError(e)
