@@ -6,16 +6,14 @@ function App() {
   const backend_url = 'http://localhost:5000'
   let data = "";
 
-  hitAPI = () => {
-    axios.get(backend_url)
-      .then(res => {
-        console.log(res.data)
-        data = res.data
-      })
-    }
-
   useEffect(() => {
-      hitAPI();
+    setTimeout(() => {
+      axios.get(backend_url)
+      .then(res => {
+        console.log(res)
+        data = res.data;
+      })
+    }, 1000);
   }, []);
 
 
